# unitorch.cli.models.xpegasus

## XPegasusProcessor

!!! tip
    **`core/process/xpegasus`** is the section for configuration of XPegasusProcessor.

::: unitorch.cli.models.xpegasus.XPegasusProcessor

## XPegasusForGeneration

!!! tip
    **`core/model/generation/xpegasus`** is the section for configuration of XPegasusForGeneration.

::: unitorch.cli.models.xpegasus.XPegasusForGeneration
